@@ -7,9 +7,9 @@
 #ifndef DBGDRIVER_H
 #define DBGDRIVER_H
 
-#include <ntqfile.h>
-#include <ntqregexp.h>
-#include <ntqcstring.h>
+#include <tqfile.h>
+#include <tqregexp.h>
+#include <tqcstring.h>
 #include <kprocess.h>
 #include <queue>
 #include <list>
