@@ -7,7 +7,7 @@
 #ifndef PGMSETTINGS_H
 #define PGMSETTINGS_H
 
-#include <ntqtabdialog.h>
+#include <tqtabdialog.h>
 
 class TQButtonGroup;
 class TQLineEdit;
